@@ -1634,7 +1634,7 @@ dlg_files_move_to_trash (GThumbWindow   *window,
 			 gpointer        done_data)
 {
 	char        *e_path;
-	GnomeVFSURI *first_uri, *trash_uri;
+	GnomeVFSURI *first_uri, *trash_uri = NULL;
 
 	g_return_if_fail (file_list != NULL);
 
@@ -2273,7 +2273,7 @@ dlg_folder_move_to_trash (GThumbWindow   *window,
 {
 	char            *parent_dir;
 	char            *e_parent_dir;
-	GnomeVFSURI     *parent_uri, *trash_uri;
+	GnomeVFSURI     *parent_uri, *trash_uri = NULL;
 
 	parent_dir = remove_level_from_path (folder);
 	e_parent_dir = escape_uri (parent_dir);
