@@ -493,7 +493,8 @@ update_notebook_page (DialogData *data,
 	case IPROP_PAGE_EXIF:
 		gth_exif_data_viewer_update (GTH_EXIF_DATA_VIEWER (data->i_exif_data_view),
 					     data->window_viewer,
-					     data->window->image_path);
+					     data->window->image_path,
+					     NULL);
 		break;
 #endif /* HAVE_LIBEXIF */
 
@@ -712,8 +713,7 @@ update_buttons_sensitivity (DialogData *data)
 
 	window = data->window;
 
-	if (! image_viewer_is_void (IMAGE_VIEWER (window->viewer))
-	    && (window->image_path != NULL))
+	if (window->image_path != NULL)
 		image_pos = gth_file_list_pos_from_path (window->file_list, 
 							 window->image_path);
 	else
