@@ -31,10 +31,10 @@
 #include <glade/glade.h>
 
 #ifdef HAVE_LIBEXIF
-#include <exif-data.h>
-#include <exif-content.h>
-#include <exif-entry.h>
-#include <exif-utils.h>
+#include <libexif/exif-data.h>
+#include <libexif/exif-content.h>
+#include <libexif/exif-entry.h>
+#include <libexif/exif-utils.h>
 #include "jpegutils/jpeg-data.h"
 #endif /* HAVE_LIBEXIF */
 
@@ -670,7 +670,7 @@ apply_tranformation_jpeg (DialogData *data,
 #ifdef HAVE_LIBEXIF
 		if ((rot_type == TRAN_ROTATE_90) || (rot_type == TRAN_ROTATE_270))
 			swap_xy_exif_fields (fd->path, data);
-		update_orientation_field (fd->path, data);
+		/* update_orientation_field (fd->path, data); see bug #318828 */
 #endif
 
 		data->files_changed_list = g_list_prepend (data->files_changed_list, 
@@ -762,7 +762,7 @@ apply_transformation (DialogData *data,
 	/* Check directory permissions. */
 
 	dir = remove_level_from_path (fd->path);
-	if (access (dir, R_OK | W_OK | X_OK) != 0) {
+	if (! check_permissions (dir, R_OK | W_OK | X_OK)) {
 		char *utf8_path;
 		utf8_path = g_filename_to_utf8 (dir, -1, NULL, NULL, NULL);
 		_gtk_error_dialog_run (GTK_WINDOW (data->dialog),
